import React from "react";
import {
	BrowserRouter as Router,
	Route,
	Switch,
	Redirect
} from "react-router-dom";
import { useSelector } from "react-redux";

import Navbar from "./components/Navbar/";
import Home from "./pages/Home/";
import SignupPage from "./pages/Signup";
import LoginPage from "./pages/Login/";
import ProfilePage from "./pages/Profile";

const App = () => {
	const currentUser = useSelector((state) => state.currentUser);

	const UnAuthRoute = ({ component: Component, ...rest }) => (
		<Route
			{...rest}
			render={(props) =>
				currentUser ? (
					<Redirect to={{ pathname: "/" }} />
				) : (
					<Component {...props} />
				)
			}
		/>
	);

	const AuthRoute = ({ component: Component, ...rest }) => (
		<Route
			{...rest}
			render={(props) =>
				currentUser ? (
					<Component {...props} />
				) : (
					<Redirect to={{ pathname: "/signin" }} />
				)
			}
		/>
	);

	return (
		<div className="App">
			<Router>
				<Navbar />
				<section className="pages">
					<Switch>
						<Route exact path="/">
							<Home />
						</Route>
						<UnAuthRoute path="/login" component={LoginPage} />
						<UnAuthRoute path="/signup" component={SignupPage} />
						<AuthRoute path="/me" component={ProfilePage} />
					</Switch>
				</section>
			</Router>
		</div>
	);
};

export default App;
