import React, { useState, useEffect } from "react";
import { useDispatch } from "react-redux";
import { useHistory } from "react-router-dom";
import jwt_decode from "jwt-decode";
import Cookies from "js-cookie";

import post from "../../../services/request/Post";
import { setCurrentUser } from "../../../redux/action";
import "./index.scss";

const LoginForm = () => {
	const [userData, setUserData] = useState(null);

	const dispatch = useDispatch();
	const history = useHistory();

	const handleSubmit = (e) => {
		e.preventDefault();
		const formdata = new FormData(e.currentTarget);
		setUserData({
			...userData,
			email: formdata.get("email"),
			password: formdata.get("password")
		});
	};

	const handleLogin = async (data) => {
		// Écrire une fonction pour vérifier plus précisément que data
		// contient bien les données nécessaires
		if (data) {
			let body = {
				user: { email: data.email, password: data.password }
			};
			const response = await post("/tokens", body);
			// Pareil ici, utiliser une fonction qui vérifie la validité des données
			if (response != null) {
				Cookies.set("token", response.data.token, {
					sameSite: "strict",
					Secure: true
				});
				const payload = {
					type: "user",
					id: jwt_decode(response.data.token).user_id,
					email: userData.email,
					username: response.data.username
				};
				dispatch(setCurrentUser(payload));
				history.push("/");
			}
		}
	};

	useEffect(() => {
		handleLogin(userData);
	}, [userData]);

	return (
		<div className="LoginForm">
			<form action="" onSubmit={handleSubmit}>
				<label htmlFor="email">Adresse email</label>
				<input type="email" id="email" name="email" />

				<label htmlFor="password">Mot de passe</label>
				<input type="password" id="password" name="password" />

				<button type="submit">Valider</button>
			</form>
		</div>
	);
};

export default LoginForm;
